% TVACOREPENC
%  
%  Synopsis
%  ========
%  
%  [PE,gv,Hvv,gt,Hvt,Htt] = tvacorepenc(tau,v,K,x,s0)
%  
%  -- Author: Mads Dyrholm --
%     Center for Visual Cognition, University of Copenhagen
%     October 2009
%  
%  Purpose 
%  =======
%  
%  This routine provides a Matlab interface to the libTVA 
%  kernel algorithm for computing the probability that an
%  item is encoded into VSTM. Do not use this function
%  unless the inputs are formatted as the exact datatypes
%  c.f. the following. For general Matlab purposes use
%  TVAPENC instead.
%  
%  Inputs
%  ======
%  
%  tau (double) Stimulus effective ontime scalar. If exponential
%  processing is used, then tau equals t-t0. If ex-gaussian 
%  processing is used, then tau is t-E[t0].
%  
%  v (double) Array of v values.
%  
%  K (double) Array of VSTM capacity CDF over [0,length(v)-1].
%
%  x (int32) Probed item scalar in [0,length(v)-1].
%
%  s0 (double) Assumed deviation on t0. Set s0>0.0 to enable 
%  the ex-gaussian model. Set to 0.0 for exponential processing.
%
%  Outputs
%  =======
%  
%  PE (double) Encoding probability.
%
%  g* (double) Gradient arrays. gv is dPE/dv, gt is dPE/dt0.
%
%  H** (double) Hessian matrices. Upper triangle of Hvv is ddPE/dvdv, 
%  lower triangle is undefined. Hvt is the vector ddPE/dvdt0, Htt is 
%  the scalar ddPE/dt0dt0.
